.. frysk documentation master file, created by
   sphinx-quickstart on Fri Jan 28 20:26:40 2022.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

.. include:: ../README.rst

.. toctree::
   :maxdepth: 2
   :caption: Contents
   :hidden:

   readme
   getting_started
   pytest-plugin
   development
   contributors
   news
